@@ -1,6 +1,6 @@
 polyDlm.main = function(x , y , q , k , show.beta = TRUE , show.summary = TRUE){
   n=length(x)
-  design  = dlm(x , y , q , show.summary = FALSE)$designMatrix
+  design  = dlm(x = x , y = y , q = q , show.summary = FALSE)$designMatrix
   tr.matrix = array(0, dim = c((q+1),(k+1)))
   design.z = array(0,dim=c(length((q+1):n),(k+1)))
   design.z.colnames = array(NA, (k+1))
